#
# spec file for package higan
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global vernumber 106
%global debug_package %{nil}
%define debianRepo https://anonscm.debian.org/cgit/pkg-games/higan.git/plain/debian/patches
Name:           higan
Version:        0.%{vernumber}
Release:        11.1
Summary:        Nintendo emulator focused on accuracy
License:        GPL-3.0 AND LGPL-2.0 AND Zlib AND ISC
Group:          System/Emulators/Other
Url:            https://byuu.org/emulation/higan
Source:         https://download.byuu.org/higan_v%{vernumber}-source.7z#/%{name}-%{version}.7z
# PATCH-FEATURE-DEBIAN
Source11:       %{name}.6
Source12:       icarus.6
# PATCH-FIX-MAGEIA
Patch0:         desktop.patch
# PATCH-FIX-SUSE
Patch1:         optflags.patch
# PATCH-FIX-UPSTREAM https://board.byuu.org/viewtopic.php?f=4&t=1661
Patch2:         icondir.patch
# PATCH-FIX-DEBIAN
Patch300:       %{debianRepo}/create_config.patch
# PATCH-FIX-DEBIAN
Patch302:       %{debianRepo}/ignore_manifests_by_default.patch
# PATCH-FIX-DEBIAN
Patch303:       %{debianRepo}/use-XDG_CONFIG_HOME.patch
# PATCH-FIX-DEBIAN
Patch304:       %{debianRepo}/use_sharedpath.patch
BuildRequires:  hicolor-icon-theme
BuildRequires:  p7zip
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(QtCore)
BuildRequires:  pkgconfig(QtGui)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(ao)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-simple)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xv)
Requires:       %{name}-icarus
ExcludeArch:    aarch64
# openSUSE Leap 42.x defaults to GCC 4
%if 0%{?suse_version} == 1315
%define _cxx g++-6
BuildRequires:  gcc6
BuildRequires:  gcc6-c++
%else
%define _cxx g++
BuildRequires:  gcc
BuildRequires:  gcc-c++
%endif

%description
Higan is an emulator for a handful of Nintendo, SEGA, NEC and Bandai
systems. It is different from other emulators in that the project
focuses on accuracy only, not speed or game-specific hacks for
compatibility. As a result, the minimum system requirements for Higan
are quite high.

%package icarus
Summary:        A file picker built for ROM launching (from higan)
Group:          Productivity/File utilities

%description icarus
Icarus is the file picker that appears when you use
"Import ROM Files..." in higan.

It can also be launched standalone, as it is really just
a file picker that only shows files with typical ROM
extensions.

%prep
%setup -q -n %{name}_v%{vernumber}-source
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch300 -p1
%patch302 -p1
%patch303 -p1
%patch304 -p1

%ifarch x86_64
perl -pi -e 's,march=native,march=k8,g;' higan/GNUmakefile
%else
perl -pi -e 's,-march=native,,g;' higan/GNUmakefile
%endif

%build
make %{?_smp_mflags} -C icarus hiro=qt compiler="%{_cxx}" platform="linux"
make %{?_smp_mflags} -C higan hiro=qt compiler="%{_cxx}" platform="linux" profile="profile_accuracy"

%install
mkdir -p %{buildroot}%{_datadir}/applications
mkdir -p %{buildroot}%{_bindir}
make prefix=%{buildroot}%{_prefix} -C icarus install
make prefix=%{buildroot}%{_prefix} -C higan install

# apply the same fix from icondir.patch to icarus
mv %{buildroot}/%{_datadir}/icons/icarus.png \
   %{buildroot}/%{_datadir}/icons/hicolor/256x256/apps/

install -d %{buildroot}%{_mandir}/man6
install -m644 %{_sourcedir}/%{name}.6 %{buildroot}%{_mandir}/man6
install -m644 %{_sourcedir}/icarus.6 %{buildroot}%{_mandir}/man6

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/%{name}
%{_datadir}/icons/hicolor/256x256/apps/%{name}.png
%{_mandir}/man6/%{name}.*

%files icarus
%{_bindir}/icarus
%{_datadir}/applications/icarus.desktop
%{_datadir}/icarus
%{_datadir}/icons/hicolor/256x256/apps/icarus.png
%{_mandir}/man6/icarus.*

%changelog
* Tue Nov 28 2017 kamikazow@opensuse.org
- Fix builds for Leap 42.2, 42.3, and Fedora 27.
  rename create-config.patch to create_config.patch to match
  debian url reference
* Sun Nov 26 2017 aavindraa@gmail.com
- update to v106:
  * restores soft-reset support for consoles
  * adds auto-saving RAM support
  * adds a new tool to save per-game text notes
  * adds 64 new SNES PAL game verifications to the icarus database
- repackage files related to "icarus", the ROM picker for higan,
  as a subpackage
- for v105 changes, see https://board.byuu.org/viewtopic.php?f=4&t=1827
- for v104 changes, see https://board.byuu.org/viewtopic.php?f=4&t=1734
- build against gtk3 instead of gtk2
- partial drop in optflags.patch
  * g++ fix merged in e9d2d56df9f59dd17ebfa2e105fb5409467e4d9f
- rebase patches:
  * icondir.patch (incorrect icon dimensions also fixed)
  * use-XDG_CONFIG_HOME.patch
  * ult.patch
  * optflags.patch (noop)
- drop find_cairo.patch: cairo resolves without issues
- match upstream patch name:
  * remove sharedpath.patch
  * add use_sharedpath.patch
- tidiness
  * cleanup with spec-cleaner
  * re-number patches taken from debian starting at 3xx
  * tag patches with upstream links
  * remove manual desktop hooks (rely on rpm triggers)
* Sat Aug 12 2017 jengelh@inai.de
- Trim history and future goals from description.
* Sat Aug  5 2017 mailaender@opensuse.org
- Add man pages
- Build with optflags
- Add patches from Debian/Mageia/Fedora to improve integration:
  * desktop.patch
  * optflags.patch
  * create-config.patch
  * ignore_manifests_by_default.patch
  * use-XDG_CONFIG_HOME.patch
  * sharedpath.patch
  * find_cairo.patch (fix for Gtk2 build though we still use Qt)
* Sat Jun 24 2017 mailaender@opensuse.org
- Update to v103
  - added SuperGrafx emulation
  - improved audio band-pass filtering for all emulated systems
  - screen rotation is now a hotkey; automatically rotates control
    bindings
  - screen rotation now supported on the Game Boy Advance as well (used
    by a small number of games)
  - massive improvements to Mega Drive emulation
  - massive code cleanups and rewrites to many CPU emulation cores
    (MOS6502, WDC65816, SPC700, etc)
  - Famicom, Master System, Mega Drive: added PAL emulation support
  - PC Engine, SuperGrafx, Master System, Game Gear, Mega Drive: added
    save state support
  - PC Engine, SuperGrafx: added PSG sound emulation
  - Master System, Game Gear: added PSG sound emulation
  - Mega Drive: added Z80 APU emulation [with help from Cydrak]
  - Mega Drive: added PSG sound emulation
  - Mega Drive: added YM2612 sound emulation [Cydrak]
  - Super Famicom: fixed Super Game Boy emulation
  - PC Engine: added save RAM support (using per-game PCE-CD backup RAM)
  - Game Boy Advance: substantial improvements to audio emulation
    quality
  - Game Boy Advance: convert scanline-based PPU renderer to a dot-based
    renderer
  - Game Boy Advance: properly initialize CPU state (fixes Classic NES
    Series games)
  - Game Boy Advance: MUL timing corrected [Jonas Quinn]
  - Mega Drive: emulate special mappers for Phantasy Star IV, Super
    Street Fighter II, etc.
  - Super Famicom: use darker luma for INIDISP=0 (large improvement to
    Final Fantasy III opening)
  - Super Famicom: fixed bugs in SMP OR1,AND1 instructions
  - cheat code database regrettably removed from official releases; will
    be made available separately
  - Famicom: PAL emulation improvements [hex\_usr]
- Changes from v102
  - PCE: latch background scroll registers (fixes Neutopia scrolling)
  - PCE: clip background attribute table scrolling (fixes Blazing Lazers
    scrolling)
  - PCE: support background/sprite enable/disable bits
  - PCE: fix large sprite indexing (fixes Blazing Lazers title screen
    sprites)
  - HuC6280: wrap zeropage accesses to never go beyond $20xx
  - HuC6280: fix alternating addresses for block move instructions
    (fixes Neutopia II)
  - HuC6280: block move instructions save and restore A,X,Y registers
  - HuC6280: emulate BCD mode (may not be 100%% correct, based on SNES
    BCD) (fixes Blazing Lazers scoring)
- Drop higan-makefile.patch as some changes were applied upstream.
- Add icondir.patch as the icon directory is still incorrect.
* Fri Dec  2 2016 aloisio@gmx.com
- Update to v101 (see changelog on https://byuu.org)
- Dropped Makefile_no_home_folder.patch and
  higan-rpmlintrc
- Added higan-makefile.patch
- Dropped Fedora since it's not a target in Emulators
- Removed libananke subpackage since the library
  is no longer present
* Sun Dec 14 2014 kamikazow@web.de
- Fedora compatibility
* Tue Apr 15 2014 seiler@b1-systems.de
- optimized spec file
- added rpmlintrc to prevent non-devel package error
* Tue Apr 15 2014 seiler@b1-systems.de
- added libananke to build
